==> engine-api-10.2.0-709.1713-sources.jar: com/xebialabs/deployit/engine/api/security/User.java <==
/**
 * Copyright 2014-2019 XebiaLabs Inc. and its affiliates. Use is subject to terms of the enclosed Legal Notice.
 */
package com.xebialabs.deployit.engine.api.security;

import com.xebialabs.deployit.engine.api.dto.AbstractDto;
import com.xebialabs.xlplatform.documentation.PublicApiRef;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * Representation of XL Deploy user
 */
@XmlRootElement(name = "user")
@PublicApiRef
public class User extends AbstractDto {

    private String username;

    private String password;

    private boolean admin;

    private String currentPassword;

    public User() {
        //
    }

    public void setCurrentPassword(String currentPassword) {
        this.currentPassword = currentPassword;
    }

    @XmlElement(name = "currentPassword", required = true)
    public String getCurrentPassword() {
        return currentPassword;
    }

    public User(String username, boolean admin) {
        this.username = username;
        this.admin = admin;
    }

    @XmlElement(name = "username")
    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    @XmlElement(name = "password", required = true)
    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    @XmlAttribute(name = "admin")
    public boolean isAdmin() {
        return admin;
    }

    public void setAdmin(boolean admin) {
        this.admin = admin;
    }

}

==> engine-api-24.1.19-608.113-sources.jar: com/xebialabs/deployit/engine/api/security/User.java <==
/**
 * Copyright 2014-2019 XebiaLabs Inc. and its affiliates. Use is subject to terms of the enclosed Legal Notice.
 */
package com.xebialabs.deployit.engine.api.security;

import com.xebialabs.deployit.engine.api.dto.AbstractDto;
import com.xebialabs.xlplatform.documentation.PublicApiRef;

import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;

/**
 * Representation of XL Deploy user
 */
@XmlRootElement(name = "user")
@PublicApiRef
public class User extends AbstractDto {

    private String username;

    private String password;

    private boolean admin;

    private String currentPassword;

    public User() {
        //
    }

    public void setCurrentPassword(String currentPassword) {
        this.currentPassword = currentPassword;
    }

    @XmlElement(name = "currentPassword", required = true)
    public String getCurrentPassword() {
        return currentPassword;
    }

    public User(String username, boolean admin) {
        this.username = username;
        this.admin = admin;
    }

    @XmlElement(name = "username")
    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    @XmlElement(name = "password", required = true)
    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    @XmlAttribute(name = "admin")
    public boolean isAdmin() {
        return admin;
    }

    public void setAdmin(boolean admin) {
        this.admin = admin;
    }

}
